setwd("~/Dropbox/AKTUELLE-PROJEKTE/Messel-Palaeopython/_Heat sensing")

##### READ DATA AND CALCULATE CROSS-SECTIONAL AREA ####
constrictores <- read.table("Jaw foramina final.txt", header = T, sep = "\t", row.names=1)
head(constrictores)
upper.pits <- constrictores$Rostral + constrictores$Supralabial.anterior + constrictores$Supralabial.posterior
upper.pits[upper.pits>=1] <- 1
lower.pits <- constrictores$Infralabial.anterior + constrictores$Infralabial.posterior
lower.pits[lower.pits>=1] <- 1
pits <- cbind(lower.pits, upper.pits)
plot(jitter(lower.pits), jitter(upper.pits))

# Calculate total cross-sectional area of foramina in upper and lower jaws
constrictores.area <- constrictores
# First, calculate area of individual foramina, then sum
# Second, calculate theoretical diameter of one foramen
# that transmitted all neurovascular structures
constrictores.area[,9:14] <- pi*(constrictores.area[,9:14]/2)^2
upper.area <- rowSums(constrictores.area[,11:14], na.rm=T)
upper.diameter <- sqrt(upper.area/pi)*2
lower.area <- rowSums(constrictores.area[,9:10], na.rm=T)
lower.diameter <- sqrt(lower.area/pi)*2
# Finally, normalize theoretical foramen size by skull length
upper.diameter.norm <- upper.diameter / constrictores$Skull.length
lower.diameter.norm <- lower.diameter / constrictores$Skull.length
train <- data.frame(cbind(upper.pits, lower.pits, upper.diameter.norm,
                          lower.diameter.norm), row.names = rownames(constrictores))

##### LOGISTIC REGRESSION #####
# Now we compute a binomial logistic regression to predict whether
# pits are present in the upper or lower jaws based on normalized, summed foramen size
upper.pit.model <- glm(train$upper.pits ~ train$upper.diameter.norm,
                       family=binomial(link='logit'))
summary(upper.pit.model)
lower.pit.model <- glm(train$lower.pits ~ train$lower.diameter.norm,
                       family=binomial(link='logit'))
summary(lower.pit.model)

# Now we compute the same only for the normalized size of the surangular foramen,
# after the observation that it is especially enlarged in many taxa
surangular.norm <- constrictores.area$Surangular.foramen/constrictores.area$Skull.length
lower.pit.surangular.model <- glm(constrictores$Infralabial.posterior ~ surangular.norm,
                                  family=binomial(link='logit'))
summary(lower.pit.surangular.model)
mental.norm <- constrictores.area$Mental.foramen/constrictores.area$Skull.length
lower.pit.mental.model <- glm(constrictores$Infralabial.anterior ~ mental.norm,
                              family=binomial(link='logit'))
summary(lower.pit.mental.model)

plot(surangular.norm, constrictores$Infralabial.posterior, xlab = "Normalized diameter of surangular foramen", ylab="Posterior infralabial pit incidence", yaxp=c(0,1,1))
plot(mental.norm, constrictores$Infralabial.anterior, xlab = "Normalized diameter of surangular foramen", ylab="Anterior infralabial pit incidence", yaxp=c(0,1,1))
plot(train$lower.diameter.norm, train$lower.pits, xlab = "Normalized total diameter of lower jaw foramina", ylab="Lower pit incidence", yaxp=c(0,1,1))
plot(train$upper.diameter.norm, train$upper.pits, xlab = "Normalized total diameter of upper jaw foramina", ylab="Upper pit incidence", yaxp=c(0,1,1))

##### Predict pit presence in Messel booids #####
fossils <- read.table("Jaw foramina fossil.txt", header = T, sep = "\t", row.names=1)

# Calculate total cross-sectional area of foramina in upper and lower jaws
fossils.area <- fossils
# First, calculate area of individual foramina, then sum
# Second, calculate theoretical diameter of one foramen
# that transmitted all neurovascular structures
fossils.area[,9:14] <- pi*(fossils.area[,9:14]/2)^2
fossil.upper.area <- rowSums(fossils.area[,11:14], na.rm=T)
fossil.upper.diameter <- sqrt(fossil.upper.area/pi)*2
fossil.lower.area <- rowSums(fossils.area[,9:10], na.rm=T)
fossil.lower.diameter <- sqrt(fossil.lower.area/pi)*2
# Finally, normalize theoretical foramen size by skull length
fossil.upper.diameter.norm <- fossil.upper.diameter / fossils$Skull.length
fossil.lower.diameter.norm <- fossil.lower.diameter / fossils$Skull.length

# Probability of upper pit incidence
# Eoconstrictor fischeri 
as.numeric(1/(1+10^(-1*(upper.pit.model$coefficients[1] + upper.pit.model$coefficients[2]*fossil.upper.diameter.norm[1]))))
# [1] 0.9216627
# Rieppelophis
as.numeric(1/(1+10^(-1*(upper.pit.model$coefficients[1] + upper.pit.model$coefficients[2]*fossil.upper.diameter.norm[2]))))
# [1] 0.1345324

# Probability of lower pit incidence
# Eoconstrictor fischeri
as.numeric(1/(1+10^(-1*(lower.pit.model$coefficients[1] + lower.pit.model$coefficients[2]*fossil.lower.diameter.norm[1]))))
# [1] 0.01573736
# Rieppelophis ermannorum
as.numeric(1/(1+10^(-1*(lower.pit.model$coefficients[1] + lower.pit.model$coefficients[2]*fossil.lower.diameter.norm[2]))))
# [1] 0.1491579
