setwd('~/Dropbox/AKTUELLE-PROJEKTE/Messel-Palaeopython/_Tail length')
library(ggplot2)
library(ggpubr)
library(factoextra)
library(MASS)
library(phytools)
library(geiger)

##### Load data and set up data #####
tail <- read.table('Sheehy_NEW_pruned.txt', header = T, sep='\t', row.names=2)
Tail_length <- tail$Rel_Tail_length * tail$Body_length
SVL <- tail$Body_length - Tail_length
tail <- cbind(tail, Tail_length, SVL)
log.tail <- tail
log.tail[,5:6] <- log10(log.tail[,5:6])
fossils <- read.table('Fossils.txt', header = T, sep='\t', row.names=2)
log.fossils <- fossils
log.fossils[,5:6] <- log10(log.fossils[,5:6])
combined <- rbind(fossils, tail)
combined.log <- rbind(log.fossils, log.tail)

##### EXPLORATORY DATA VISUALIZATION #####
#     with untransformed data
gghistogram(tail, x="SVL", bins=10, color = "Ecology", fill="Ecology",
            palette=c("limegreen", "tan4", "steelblue2", "tan"))
gghistogram(tail, x="Tail_length", bins=10, color = "Ecology", fill="Ecology",
            palette=c("limegreen", "tan4", "steelblue2", "tan"))

#     with log10-transformed data
gghistogram(log.tail, x="SVL", bins=10, color = "Ecology", fill="Ecology",
            palette=c("limegreen", "tan4", "steelblue2", "tan"))
gghistogram(log.tail, x="Tail_length", bins=10, color = "Ecology", fill="Ecology",
            palette=c("limegreen", "tan4", "steelblue2", "tan"))

##### Principle components analysis #####
#     without Eoconstrictor
tail.pca <- prcomp(log.tail[,5:6], scale = T)
fviz_eig(tail.pca, yscale="sqrt")
fviz_pca_ind(tail.pca, axes=c(1,2), label="none", repel = TRUE,
             habillage = log.tail$Ecology,
             palette = c("steelblue2", "limegreen", "black", "tan"))
fviz_pca_var(tail.pca, axes=c(1,2), repel = TRUE)
fviz_ellipses(tail.pca, axes=c(1,2), habillage = log.tail$Ecology,
              palette = c("steelblue2", "limegreen", "black", "tan"),
              pointsize = 2, geom = "point", addEllipses = TRUE)
#     with Eoconstrictor
fossil.tail.pca <- prcomp(combined.log[,5:6], scale = T)
fviz_eig(fossil.tail.pca, yscale="sqrt")
fviz_pca_ind(fossil.tail.pca, axes=c(1,2), label="none", repel = TRUE, 
             habillage = combined$Ecology, palette = c("red", "steelblue2", "limegreen", "black", "tan"),
             pointsize = 2)
fviz_pca_var(fossil.tail.pca, axes=c(1,2), repel = TRUE)
# Get loadings on 2 PC axes for normal PCA including fossil
# fossil.tail.pca$rotation
# PC1        PC2
# Tail_length 0.7071068  0.7071068
# SVL         0.7071068 -0.7071068

tail.levels <- levels(combined.log$Ecology)
tail.color <- c("red", "steelblue2", "limegreen", "black", "tan")
plot(fossil.tail.pca$x, type = 'n')
for (i in 1:5) {
  points(fossil.tail.pca$x[combined.log$Ecology==tail.levels[i],1],
         fossil.tail.pca$x[combined.log$Ecology==tail.levels[i],2],
         pch=16, col = tail.color[i])
}
legend(x="topright", legend=c("fossil", "aquatic", "arboreal", "generalist", "ground-dwelling"), pch=16, cex=0.7, col = tail.color, xjust=1)

###### Linear Discriminant Analysis #####
# Here we use log-transformed data, so that distribution of variables is closer to normal
f <- paste(names(log.tail)[2], " ~ ", paste(names(log.tail)[5:6], collapse=" + "))
log.tail.lda <- lda(as.formula(paste(f)), data=log.tail[,c(2,5:6)])
fischeri.lda.predict <- predict(log.tail.lda, newdata=log.fossils[,5:6])
fischeri.lda.predict
#$class
#[1] generalist
#Levels: aquatic arboreal generalist ground-dwelling
#
#$posterior
#aquatic arboreal generalist ground-dwelling
#Eoconstrictor fischeri 0.05219467 0.149524  0.6171534       0.1811279
#
#$x
#LD1      LD2
#Eoconstrictor fischeri 0.7461401 2.044795

##### PHYLOGENETIC PCA OF TAIL AND BODY LENGTH IN EXTANT FORMS #####
tree <- read.tree('Pyron_etal_2013_Squamata_Newick.txt')
match(row.names(log.tail), tree$tip.label)
all <- 1:4162
prune <- all[-match(row.names(log.tail), tree$tip.label)]
tree.prune <- drop.tip(tree, tip = prune)
tailOverlap <- treedata(tree, log.tail)
SVL.test <- log.tail$SVL
names(SVL.test) <- row.names(log.tail)
Tail.test <- log.tail$Tail_length
names(Tail.test) <- row.names(log.tail)
lambda.svl <- fitContinuous(tailOverlap$phy, SVL.test, model = "lambda")
# lambda = 0.838409
kappa.svl <- fitContinuous(tailOverlap$phy, SVL.test, model = "kappa")
# kappa = 0.588619
lambda.tail <- fitContinuous(tailOverlap$phy, Tail.test, model = "lambda")
# lambda = 0.978866
kappa.tail <- fitContinuous(tailOverlap$phy, Tail.test, model = "kappa")
# kappa = 0.765113

tail.phyl.pca <- phyl.pca(tree.prune, log.tail[,5:6])
# Get the loadings on the 2 PC axes for pPCA
# tail.phyl.pca$L
# PC1        PC2
# Tail_length -0.9776741  0.2101268
# SVL         -0.9180183 -0.3965381
tail.levels <- levels(log.tail$Ecology)
tail.color <- c("steelblue2", "limegreen", "black", "tan")
plot(tail.phyl.pca$S, type = 'n')
for (i in 1:4) {
  points(tail.phyl.pca$S[log.tail$Ecology==tail.levels[i],], pch=16, col = tail.color[i])
}
legend(x="topright", legend=c("aquatic", "arboreal", "generalist", "ground-dwelling"), pch=16, cex=0.7, col = tail.color, xjust=1)

# Correlation between scores on 2 PC's for normal and pPCA
plot(fossil.tail.pca$x[-182,1], tail.phyl.pca$S[,1])
plot(fossil.tail.pca$x[-182,2], tail.phyl.pca$S[,2])
cor.test(fossil.tail.pca$x[-182,1], tail.phyl.pca$S[,1])
# P = 0.01, rho = 0.191
cor(fossil.tail.pca$x[-182,2], tail.phyl.pca$S[,2])
# P < 2.2 x 10^-16, rho = 0.561
